@@ -51,9 +51,11 @@ def catch_error(exc):
 		(exc[0] == 'invalid mode: rb' or
 		 errno.errorcode.has_key(exc[0]) and
 		 errno.errorcode[exc[0]] in ('EPERM', 'ENOENT', 'EACCES', 'EBUSY',
-									 'EEXIST', 'ENOTDIR', 'ENAMETOOLONG',
-									 'EINTR', 'ENOTEMPTY', 'EIO', 'ETXTBSY',
-									 'ESRCH', 'EINVAL', 'EDEADLOCK'))):
+									 'EEXIST', 'ENOTDIR',
+									 'ENAMETOOLONG', 'EINTR',
+									 'ENOTEMPTY', 'EIO', 'ETXTBSY',
+									 'ESRCH', 'EINVAL', 'EDEADLOCK',
+									 'EDEADLK'))):
 		return 1
 	return 0
 
